@@ -109,6 +109,15 @@ static void set_headers(reference *ref, struct curl_slist *newheaders){
                           newheaders ? newheaders : default_headers()));
 }
 
+static int default_verbose_cb(CURL *handle, curl_infotype type, char *data, size_t size, void *userptr){
+  if(type < 3){
+    char prefix = type == CURLINFO_TEXT ? '*' : (type == CURLINFO_HEADER_IN ? '<' : '>');
+    REprintf("%c %.*s", prefix, (int) size, data);
+  }
+  return 0;
+}
+
+
 /* These are defaulst that we always want to set */
 static void set_handle_defaults(reference *ref){
 
@@ -121,22 +130,24 @@ static void set_handle_defaults(reference *ref){
   curl_easy_setopt(handle, CURLOPT_HEADERFUNCTION, append_buffer);
   curl_easy_setopt(handle, CURLOPT_HEADERDATA, &(ref->resheaders));
 
-  /* Only set a default CA bundle for openssl */
+  /* Respect CURL_CA_BUNDLE like base R, except for Schannel on Windows */
+  const char *ca_bundle = getenv("CURL_CA_BUNDLE");
   #ifdef _WIN32
   curl_easy_setopt(handle, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NO_REVOKE);
   struct curl_tlssessioninfo *tlsinfo = NULL;
   if(curl_easy_getinfo(handle, CURLINFO_TLS_SSL_PTR, &tlsinfo) == CURLE_OK){
-    if(tlsinfo->backend == CURLSSLBACKEND_OPENSSL) {
-      const char *ca_bundle = getenv("CURL_CA_BUNDLE");
-      if(ca_bundle != NULL) {
-        curl_easy_setopt(handle, CURLOPT_CAINFO, ca_bundle);
-      } else {
-        curl_easy_setopt(handle, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NO_REVOKE | CURLSSLOPT_NATIVE_CA);
-      }
+    if(tlsinfo->backend == CURLSSLBACKEND_OPENSSL && ca_bundle == NULL) {
+      curl_easy_setopt(handle, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NO_REVOKE | CURLSSLOPT_NATIVE_CA);
+    } else if(tlsinfo->backend == CURLSSLBACKEND_SCHANNEL){
+      ca_bundle = NULL;
     }
   }
   #endif
 
+  if(ca_bundle != NULL) {
+    curl_easy_setopt(handle, CURLOPT_CAINFO, ca_bundle);
+  }
+
   /* needed to support compressed responses */
   assert(curl_easy_setopt(handle, CURLOPT_ENCODING, ""));
 
@@ -188,6 +199,9 @@ static void set_handle_defaults(reference *ref){
 #ifdef HAS_CURLOPT_EXPECT_100_TIMEOUT_MS
   assert(curl_easy_setopt(handle, CURLOPT_EXPECT_100_TIMEOUT_MS, 0L));
 #endif
+
+  /* Send verbose outout to R front-end virtual stderr */
+  assert(curl_easy_setopt(handle, CURLOPT_DEBUGFUNCTION, default_verbose_cb));
 }
 
 SEXP R_new_handle(void){
@@ -196,7 +210,7 @@ SEXP R_new_handle(void){
   ref->handle = curl_easy_init();
   total_handles++;
   set_handle_defaults(ref);
-  SEXP prot = PROTECT(allocVector(VECSXP, 6)); //for protecting callback functions
+  SEXP prot = PROTECT(allocVector(VECSXP, 7)); //for protecting callback functions
   SEXP ptr = PROTECT(R_MakeExternalPtr(ref, R_NilValue, prot));
   R_RegisterCFinalizerEx(ptr, fin_handle, TRUE);
   setAttrib(ptr, R_ClassSymbol, mkString("curl_handle"));
@@ -302,6 +316,13 @@ SEXP R_handle_setopt(SEXP ptr, SEXP keys, SEXP values){
                               (curl_ssl_ctx_callback) R_curl_callback_ssl_ctx));
       assert(curl_easy_setopt(handle, CURLOPT_SSL_CTX_DATA, val));
       SET_VECTOR_ELT(prot, 5, val); //protect gc
+    } else if (key == CURLOPT_SEEKFUNCTION) {
+      if (TYPEOF(val) != CLOSXP)
+        error("Value for option %s (%d) must be a function.", optname, key);
+      assert(curl_easy_setopt(handle, CURLOPT_SEEKFUNCTION,
+                              (curl_seek_callback) R_curl_callback_seek));
+      assert(curl_easy_setopt(handle, CURLOPT_SEEKDATA, val));
+      SET_VECTOR_ELT(prot, 6, val); //protect gc
     } else if (key == CURLOPT_URL) {
       /* always use utf-8 for urls */
       const char * url_utf8 = translateCharUTF8(STRING_ELT(val, 0));
@@ -519,6 +540,9 @@ SEXP R_get_handle_received(SEXP ptr){
   return Rf_ScalarReal((double) dl);
 }
 
+SEXP R_get_handle_mtime(SEXP ptr){
+  return make_filetime(get_handle(ptr));
+}
 
 SEXP R_total_handles(void){
   return(ScalarInteger(total_handles));
