@@ -10,7 +10,7 @@ void check_interrupt_fn(void *dummy) {
   R_CheckUserInterrupt();
 }
 
-int pending_interrupt() {
+int pending_interrupt(void) {
   return !(R_ToplevelExec(check_interrupt_fn, NULL));
 }
 
